http test case changes

Dependencies:   ublox-cellular-driver-gen gnss ublox-cellular-base ublox-at-cellular-interface-ext

Revision:
5:540b2d19fc5c
Parent:
4:13a84f6cc800
Child:
6:7a33376899e5
--- a/main.cpp	Thu Jun 08 09:11:45 2017 +0100
+++ b/main.cpp	Fri Jun 09 11:46:38 2017 +0000
@@ -115,8 +115,9 @@
 }
 
 /* This example program for the u-blox C030 and C027 boards instantiates
  * the UbloxAtCellularInterface to do FTP, HTTP and CellLocate operations.
  * It uses test.rebex.net for FTP testing and mbed.org for HTTP GET testing.
  * Progress may be monitored with a serial terminal running at 9600 baud.
  * The LED on the C030 board will turn green when this program is
  * operating correctly, pulse blue when an FTP get, HTTP get or CellLocate
@@ -131,7 +132,8 @@
     char buf[1024];
     int httpProfile;
     int numRes;
-    GnssSerial gnssSerial;
+    GnssSerial gnssSerial; // This needed purely to power on the GNSS chip in 
+                           // order that Cell Locate on the module can use it
     InterruptIn userButton(SW0);
     
     // Attach a function to the user button
@@ -193,10 +195,10 @@
         // HTTP OPERATIONS
         // Set up HTTP parameters
         printf("=== HTTP ===\n");
-        printf("Performing HTTP GET on \"mbed.org\"...\n");
+        printf("Performing HTTP GET on \"developer.mbed.org\"...\n");
         httpProfile = interface->httpAllocProfile();
         interface->httpSetTimeout(httpProfile, 30000);
-        interface->httpSetPar(httpProfile, UbloxATCellularInterfaceExt::HTTP_SERVER_NAME, "mbed.org");
+        interface->httpSetPar(httpProfile, UbloxATCellularInterfaceExt::HTTP_SERVER_NAME, "developer.mbed.org");
         
         // Do the HTTP command
         err = interface->httpCommand(httpProfile, UbloxATCellularInterfaceExt::HTTP_GET,
@@ -210,7 +212,7 @@
                    "------------------------------------------------------------------------------------\n", buf);
         } else {
             bad();
-            printf("Unable to get \"/media/uploads/mbed_official/hello.txt\" from \"mbed.org\", "
+            printf("Unable to get \"/media/uploads/mbed_official/hello.txt\" from \"developer.mbed.org\", "
                    "error class %d, error code %d.\n", err->eClass, err->eCode);
         }
 
@@ -241,6 +243,7 @@
                 }
             }
             wait_ms(5000);
+            printf("[Checking user button]\n");
         }
         
         pulseEvent();
@@ -115,8 +115,9 @@
 
 /* This example program for the u-blox C030 and C027 boards instantiates
- * the UbloxAtCellularInterface to do FTP, HTTP and CellLocate operations.
- * It uses test.rebex.net for FTP testing and mbed.org for HTTP GET testing.
+ * the UbloxAtCellularInterfaceExt to do FTP, HTTP and CellLocate operations.
+ * It uses the site test.rebex.net for FTP testing and the site
+ * developer.mbed.org for HTTP GET testing.
  * Progress may be monitored with a serial terminal running at 9600 baud.
  * The LED on the C030 board will turn green when this program is